@@ -164,19 +164,21 @@ void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
 #define QUIRK_VIBINV	(1 << 21)	/* Vibrato has inverse waveform */
 #define QUIRK_PRENV	(1 << 22)	/* Portamento resets envelope & fade */
 #define QUIRK_S3MLFO	(1 << 23)	/* S3M-style LFO waveforms */
-#define QUIRK_RTDELAY	(1 << 24)	/* Delay effect retrigs instrument */
+#define QUIRK_S3MRTG	(1 << 24)	/* S3M-style retrig when count == 0 */
+#define QUIRK_RTDELAY	(1 << 25)	/* Delay effect retrigs instrument */
+#define QUIRK_MLKDLY	(1 << 26)	/* MilkyTracker-style delay effect */
 
 #define HAS_QUIRK(x)	(m->quirk & (x))
 
 
 /* Format quirks */
 #define QUIRKS_ST3		(QUIRK_S3MLOOP | QUIRK_VOLPDN | QUIRK_FINEFX | \
-				 QUIRK_S3MLFO  )
+				 QUIRK_S3MLFO  | QUIRK_S3MRTG )
 #define QUIRKS_FT2		(QUIRK_RTDELAY | QUIRK_FINEFX )
 #define QUIRKS_IT		(QUIRK_S3MLOOP | QUIRK_FINEFX | QUIRK_VIBALL | \
 				 QUIRK_ENVFADE | QUIRK_ITVPOR | QUIRK_KEYOFF | \
 				 QUIRK_VIRTUAL | QUIRK_FILTER | QUIRK_S3MLFO | \
-				 QUIRK_IGSTPOR )
+				 QUIRK_IGSTPOR | QUIRK_S3MRTG )
 
 /* DSP effects */
 #define DSP_EFFECT_CUTOFF	0x02
@@ -231,6 +233,7 @@ struct module_data {
 #define READ_EVENT_FT2	1
 #define READ_EVENT_ST3	2
 #define READ_EVENT_IT	3
+#define READ_EVENT_MED	4
 	int read_event_type;
 	int smpctl;			/* sample control flags */
 	struct ord_data xxo_info[XMP_MAX_MOD_LENGTH];
