@@ -24,9 +24,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <time.h>
-#include <sys/time.h>
-#include <unistd.h>
 #include <stdarg.h>
 
 #include "format.h"
