@@ -42,9 +42,9 @@ extern const struct format_loader med4_loader;
 /* extern const struct format_loader dmf_loader; */
 extern const struct format_loader rtm_loader;
 extern const struct format_loader pt3_loader;
-extern const struct format_loader tcb_loader;
+/* extern const struct format_loader tcb_loader; */
 extern const struct format_loader dt_loader;
-extern const struct format_loader gtk_loader;
+/* extern const struct format_loader gtk_loader; */
 /* extern const struct format_loader dtt_loader; */
 extern const struct format_loader mgt_loader;
 extern const struct format_loader arch_loader;
@@ -108,9 +108,9 @@ const struct format_loader *const format_loader[NUM_FORMATS + 2] = {
 	&chip_loader,
 	&rtm_loader,
 	&pt3_loader,
-	&tcb_loader,
+	/* &tcb_loader, */
 	&dt_loader,
-	&gtk_loader,
+	/* &gtk_loader, */
 	/* &dtt_loader, */
 	&mgt_loader,
 	&arch_loader,
@@ -144,11 +144,14 @@ static const char *_farray[NUM_FORMATS + NUM_PW_FORMATS + 1] = { NULL };
 
 char **format_list()
 {
-	int count, i, j;
+	int count, i;
 
 	if (_farray[0] == NULL) {
 		for (count = i = 0; format_loader[i] != NULL; i++) {
+
 			if (strcmp(format_loader[i]->name, "prowizard") == 0) {
+				int j;
+
 				for (j = 0; pw_format[j] != NULL; j++) {
 					_farray[count++] = pw_format[j]->name;
 				}
