@@ -205,7 +205,7 @@ static int get_inst(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	i = hio_read8(f);		/* instrument number */
 
 	hio_read(&mod->xxi[i].name, 1, 28, f);
-	str_adj((char *)mod->xxi[i].name);
+	adjust_string((char *)mod->xxi[i].name);
 
 	mod->xxi[i].nsm = hio_read8(f);
 
@@ -286,7 +286,7 @@ static int get_inst(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 		hio_read32b(f);	/* size */
 	
 		hio_read(&mod->xxs[data->snum].name, 1, 28, f);
-		str_adj((char *)mod->xxs[data->snum].name);
+		adjust_string((char *)mod->xxs[data->snum].name);
 	
 		mod->xxi[i].sub[j].pan = hio_read8(f) * 4;
 		if (mod->xxi[i].sub[j].pan == 0)	/* not sure about this */
