@@ -90,7 +90,7 @@ static const uint8 fx[] = {
 	/* U */ FX_FINE_VIBRATO,
 	/* V */ FX_GLOBALVOL,
 	/* W */ FX_GVOL_SLIDE,
-	/* X */ FX_MASTER_PAN,
+	/* X */ FX_SETPAN,
 	/* Y */ FX_PANBRELLO,
 	/* Z */ FX_FLT_CUTOFF
 };
@@ -145,7 +145,7 @@ static void xlat_fx(int c, struct xmp_event *e, uint8 *last_fxp, int new_fx)
 	    e->fxp &= 0x0f;
 	    break;
 	case 0x8:		/* Set pan position */
-	    e->fxt = FX_MASTER_PAN;
+	    e->fxt = FX_SETPAN;
 	    e->fxp = l << 4;
 	    break;
 	case 0x9:		/* 0x91 = set surround -- NOT IMPLEMENTED */
@@ -157,7 +157,7 @@ static void xlat_fx(int c, struct xmp_event *e, uint8 *last_fxp, int new_fx)
 	case 0xc:		/* Note cut */
 	case 0xd:		/* Note delay */
 	    if ((e->fxp = l) == 0)
-		e->fxp++;	/* SD0 and SC0 becomes SD1 and SC1 */
+		e->fxp++;	/* SD0 and SC0 become SD1 and SC1 */
 	    e->fxp |= h << 4;
 	    break;
 	case 0xe:		/* Pattern row delay */
@@ -223,7 +223,7 @@ static void xlat_volfx(struct xmp_event *event)
     } else if (b >= 128 && b <= 192) {	/* pan */
 	if (b == 192)
 	    b = 191;
-	event->f2t = FX_MASTER_PAN;
+	event->f2t = FX_SETPAN;
 	event->f2p = (b - 128) << 2;
     } else if (b >= 193 && b <= 202) {	/* G */
 	event->f2t = FX_TONEPORTA;
@@ -517,27 +517,6 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
     if (~ifh.flags & IT_USE_INST)
 	mod->ins = mod->smp;
 
-    if (ifh.special & IT_HAS_MSG) {
-	if ((m->comment = malloc(ifh.msglen + 1)) == NULL)
-	    goto err4;
-	i = hio_tell(f);
-	hio_seek(f, start + ifh.msgofs, SEEK_SET);
-
-	D_(D_INFO "Message length : %d", ifh.msglen);
-
-	for (j = 0; j < ifh.msglen; j++) {
-	    b = hio_read8(f);
-	    if (b == '\r')
-		b = '\n';
-	    if ((b < 32 || b > 127) && b != '\n' && b != '\t')
-		b = '.';
-	    m->comment[j] = b;
-	}
-	m->comment[j] = 0;
-
-	hio_seek(f, i, SEEK_SET);
-    }
-
     if (instrument_init(mod) < 0)
 	goto err4;
 
@@ -654,7 +633,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		    sub->nna = i2h.nna;
 		    sub->dct = i2h.dct;
 		    sub->dca = dca2nna[i2h.dca & 0x03];
-		    sub->pan = i2h.dfp & 0x80 ? 0x80 : i2h.dfp * 4;
+		    sub->pan = i2h.dfp & 0x80 ? -1 : i2h.dfp * 4;
 		    sub->ifc = i2h.ifc;
 		    sub->ifr = i2h.ifr;
 	        }
@@ -893,8 +872,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    if (0 != hio_seek(f, start + ish.sample_ptr, SEEK_SET))
 	    	goto err4;
 
-	    //TODO: use proper unsigned values in xmp_sample structure
-	    if ((unsigned)xxs->lpe > (unsigned)xxs->len || (unsigned)xxs->lps >= (unsigned)xxs->lpe)
+	    if (xxs->lpe > xxs->len || xxs->lps >= xxs->lpe)
 	    	xxs->flg &= ~XMP_SAMPLE_LOOP;
 
 	    if (~ish.convert & IT_CVT_SIGNED)
@@ -1116,6 +1094,27 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
     free(pp_smp);
     free(pp_ins);
 
+    /* Song message */
+
+    if (ifh.special & IT_HAS_MSG) {
+	if ((m->comment = malloc(ifh.msglen + 1)) != NULL) {
+	    hio_seek(f, start + ifh.msgofs, SEEK_SET);
+
+	    D_(D_INFO "Message length : %d", ifh.msglen);
+
+	    for (j = 0; j < ifh.msglen; j++) {
+	        b = hio_read8(f);
+	        if (b == '\r') {
+		    b = '\n';
+	        } else if ((b < 32 || b > 127) && b != '\n' && b != '\t') {
+		    b = '.';
+		}
+	        m->comment[j] = b;
+	    }
+	    m->comment[j] = 0;
+	}
+    }
+
     /* Format quirks */
 
     m->quirk |= QUIRKS_IT;
