@@ -64,6 +64,8 @@ static int mmd1_test(HIO_HANDLE *f, char *t, const int start)
 	return 0;
 }
 
+/* Number of octaves in IFFOCT samples */
+static const int num_oct[6] = { 5, 3, 2, 4, 6, 7 };
 
 static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 {
@@ -88,7 +90,7 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	uint32 songname_offset;
 	uint32 iinfo_offset;
 	int pos;
-	int bpm_on, bpmlen, med_8ch;
+	int bpm_on, bpmlen, med_8ch, hexvol;
 
 	LOAD_INIT();
 
@@ -155,6 +157,7 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	 */
 	m->c4rate = C4_NTSC_RATE;
 	m->quirk |= song.flags & FLAG_STSLIDE ? 0 : QUIRK_VSALL | QUIRK_PBALL;
+	hexvol = song.flags & FLAG_VOLHEX;
 	med_8ch = song.flags & FLAG_8CHANNEL;
 	bpm_on = song.flags2 & FLAG2_BPM;
 	bpmlen = 1 + (song.flags2 & FLAG2_BMASK);
@@ -190,6 +193,8 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		if (type == -1) {			/* type is synth? */
 			hio_seek(f, 14, SEEK_CUR);
 			mod->smp += hio_read16b(f);		/* wforms */
+		} else if (type >= 1 && type <= 6) {
+			mod->smp += num_oct[type - 1];
 		} else {
 			mod->smp++;
 		}
@@ -317,20 +322,23 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 					event->note = e[0] & 0x7f;
 					if (event->note)
 						event->note +=
-						    48 + song.playtransp;
+						    12 + song.playtransp;
+
+					if (event->note < 0 || event->note >=
+								XMP_MAX_KEYS)
+						event->note = 0;
+
 					event->ins = e[1] & 0x3f;
 
 					/* Decay */
 					if (event->ins && !event->note) {
-						event->f2t = FX_MED_DECAY;
-						event->f2p = event->ins;
-						event->ins = 0;
+						event->f2t = FX_MED_HOLD;
 					}
 
 					event->fxt = e[2];
 					event->fxp = e[3];
-					mmd_xlat_fx(event, bpm_on,
-							bpmlen, med_8ch);
+					mmd_xlat_fx(event, bpm_on, bpmlen,
+							med_8ch, hexvol);
 				}
 			}
 		} else {		/* MMD0 */
@@ -343,22 +351,25 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 					event = &EVENT(i, k, j);
 					event->note = e[0] & 0x3f;
 					if (event->note)
-						event->note += 48;
+						event->note += 12;
+
+					if (event->note < 0 || event->note >=
+								XMP_MAX_KEYS)
+						event->note = 0;
+
 					event->ins =
 					    (e[1] >> 4) | ((e[0] & 0x80) >> 3)
 					    | ((e[0] & 0x40) >> 1);
 
 					/* Decay */
 					if (event->ins && !event->note) {
-						event->f2t = FX_MED_DECAY;
-						event->f2p = event->ins;
-						event->ins = 0;
+						event->f2t = FX_MED_HOLD;
 					}
 
 					event->fxt = e[1] & 0x0f;
 					event->fxp = e[2];
-					mmd_xlat_fx(event, bpm_on,
-							bpmlen, med_8ch);
+					mmd_xlat_fx(event, bpm_on, bpmlen,
+							med_8ch, hexvol);
 				}
 			}
 		}
@@ -379,11 +390,9 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	for (smp_idx = i = 0; i < mod->ins; i++) {
 		int smpl_offset;
 		char name[40] = "";
-		struct xmp_subinstrument *sub;
-		struct xmp_sample *xxs;
 
 		if (hio_seek(f, start + smplarr_offset + i * 4, SEEK_SET) != 0)
-		  return -1;
+			return -1;
 		smpl_offset = hio_read32b(f);
 
 		D_(D_INFO "sample %d smpl_offset = 0x%08x", i, smpl_offset);
@@ -451,66 +460,38 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			continue;
 		}
 
-		if (instr.type != 0)
+		if (instr.type >= 1 && instr.type <= 6) {	/* IFFOCT */
+			int ret;
+			const int oct = num_oct[instr.type - 1];
+
+			hio_seek(f, start + smpl_offset + 6, SEEK_SET);
+
+			ret = mmd_load_iffoct_instrument(f, m, i, smp_idx,
+				&instr, oct, &exp_smp, &song.sample[i]);
+
+			if (ret < 0)
+				return -1;
+
+			smp_idx += oct;
+
 			continue;
+		}
 
-		/* instr type is sample */
-		mod->xxi[i].nsm = 1;
-		if (subinstrument_alloc(mod, i, 1) < 0)
-			return -1;
+		if (instr.type == 0) {			/* Sample */
+			int ret;
 
-		sub = &mod->xxi[i].sub[0];
+			hio_seek(f, start + smpl_offset + 6, SEEK_SET);
 
-		sub->vol = song.sample[i].svol;
-		sub->pan = 0x80;
-		sub->xpo = song.sample[i].strans;
-		sub->sid = smp_idx;
-		sub->fin = exp_smp.finetune << 4;
+			ret = mmd_load_sampled_instrument(f, m, i, smp_idx,
+				&instr, &expdata, &exp_smp, &song.sample[i],
+				ver);
 
-		xxs = &mod->xxs[smp_idx];
+			if (ret < 0)
+				return -1;
 
-		xxs->len = instr.length;
-		xxs->lps = 2 * song.sample[i].rep;
-		xxs->lpe = xxs->lps + 2 * song.sample[i].replen;
-		xxs->flg = 0;
+			smp_idx++;
 
-		if (song.sample[i].replen > 1)
-			xxs->flg |= XMP_SAMPLE_LOOP;
-
-		D_(D_INFO "  %05x %05x %05x %02x %+3d %+1d",
-				xxs->len, xxs->lps, xxs->lpe,
-				sub->vol, sub->xpo, sub->fin >> 4);
-
-		if (hio_seek(f, start + smpl_offset + 6, SEEK_SET) != 0)
-		  return -1;
-		if (load_sample(m, f, 0, xxs, NULL) < 0)
-			return -1;
-
-		smp_idx++;
-	}
-
-	/*
-	 * Adjust event note data in patterns
-	 */
-
-	/* Restrict non-synth instruments to 3 octave range.
-	 * Checked in MMD0 with med.egypian/med.medieval from Lemmings 2
-	 * and MED.ParasolStars, MMD1 with med.Lemmings2
-	 */
-	for (i = 0; i < mod->pat; i++) {
-		for (j = 0; j < mod->xxp[i]->rows; j++) {
-			for (k = 0; k < mod->chn; k++) {
-				event = &EVENT(i, k, j);
-
-				if (!event->note || !event->ins)
-					continue;
-
-				/* Not a synth instrument */
-				if (!MED_MODULE_EXTRAS(*m)->wav_table[event->ins - 1]) {
-					while (event->note > (48 + 36))
-						event->note -= 12;
-				}
-			}
+			continue;
 		}
 	}
 
@@ -519,5 +500,7 @@ static int mmd1_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		mod->xxc[i].pan = (((i + 1) / 2) % 2) * 0xff;
 	}
 
+	m->read_event_type = READ_EVENT_MED;
+
 	return 0;
 }
