@@ -58,7 +58,8 @@ static int get_8ch_tempo(int tempo)
 	}
 }
 
-void mmd_xlat_fx(struct xmp_event *event, int bpm_on, int bpmlen, int med_8ch)
+void mmd_xlat_fx(struct xmp_event *event, int bpm_on, int bpmlen, int med_8ch,
+		 int hexvol)
 {
 	switch (event->fxt) {
 	case 0x00:
@@ -150,6 +151,10 @@ void mmd_xlat_fx(struct xmp_event *event, int bpm_on, int bpmlen, int med_8ch)
 		/* SET VOLUME 0C
 		 * Overrides the default volume of an instrument.
 		 */
+		if (!hexvol) {
+			int p = event->fxp;
+			event->fxp = (p >> 8) * 10 + (p & 0xff);
+		}
 		break;
 	case 0x0d:
 		/* VOLUME SLIDE 0D
@@ -296,6 +301,40 @@ void mmd_xlat_fx(struct xmp_event *event, int bpm_on, int bpmlen, int med_8ch)
 		 */
 		event->fxt = FX_PATT_DELAY;
 		break;
+	case 0x1f:
+		/* Command 1F: NOTE DELAY AND RETRIGGER
+		 * (Protracker commands EC and ED)
+		 * Gives you accurate control over note playing. You can
+		 * delay the note any number of ticks, and initiate fast
+		 * retrigger. Level 1 = note delay value, level 2 = retrigger
+		 * value.
+		 */
+		if (MSN(event->fxp)) {
+			/* delay */
+			event->fxt = FX_EXTENDED;
+			event->fxp = 0xd0 | (event->fxp >> 4);
+		} else if (LSN(event->fxp)) {
+			/* retrig */
+			event->fxt = FX_EXTENDED;
+			event->fxp = 0x90 | (event->fxp & 0x0f);
+		}
+		break;
+	case 0x2e:
+		/* Command 2E: SET TRACK PANNING
+		 * Allows track panning to be changed during play. The track
+		 * on which the player command appears is the track affected.
+		 * The command level is in signed hex: $F0 to $10 = -16 to 16
+		 * decimal.
+		 */
+		if (event->fxp >= 0xf0 || event->fxp <= 0x10) {
+			int fxp = (signed char)event->fxp + 16;
+			fxp <<= 3;
+			if (fxp == 0x100)
+				fxp--;
+			event->fxt = FX_SETPAN;
+			event->fxp = fxp;
+		}
+		break;
 	default:
 		event->fxt = event->fxp = 0;
 		break;
@@ -482,9 +521,11 @@ int mmd_load_sampled_instrument(HIO_HANDLE *f, struct module_data *m, int i,
 	sub->xpo = sample->strans + 36;
 	if (ver >= 2 && expdata->s_ext_entrsz > 4) {	/* MMD2+ */
 		sub->xpo += exp_smp->default_pitch;
+#if 0
 		if (ver == 2) {
 			sub->xpo += 24;			/* ??!? */
 		}
+#endif
 	}
 	sub->sid = smp_idx;
 	sub->fin = exp_smp->finetune << 4;
@@ -514,23 +555,27 @@ int mmd_load_sampled_instrument(HIO_HANDLE *f, struct module_data *m, int i,
 	 * usage for both samples is length * 2 bytes.
 	 */
 
-        /* Restrict sampled instruments to 3 octave range.
+        /* Restrict sampled instruments to 3 octave range except for MMD3.
          * Checked in MMD0 with med.egypian/med.medieval from Lemmings 2
          * and MED.ParasolStars, MMD1 with med.Lemmings2
          */
-	for (j = 0; j < 9; j++) {
-		for (k = 0; k < 12; k++) {
-			int xpo = 0;
 
-			if (j <= 0)
-				xpo = 12 * (1 - j);
-			else if (j >= 4)
-				xpo = -12 * (j - 3);
-
-			xxi->map[12 * j + k].xpo = xpo;
+	if (ver < 3) {
+		for (j = 0; j < 9; j++) {
+			for (k = 0; k < 12; k++) {
+				int xpo = 0;
+	
+				if (j < 1)
+					xpo = 12 * (1 - j);
+				else if (j > 3)
+					xpo = -12 * (j - 3);
+	
+				xxi->map[12 * j + k].xpo = xpo;
+			}
 		}
 	}
 
+
 	if (load_sample(m, f, SAMPLE_FLAG_BIGEND, xxs, NULL) < 0) {
 		return -1;
 	}
