@@ -84,7 +84,6 @@ static void set_effect_defaults(struct context_data *ctx, int note,
 	struct module_data *m = &ctx->m;
 
 	if (sub != NULL && note >= 0) {
-		xc->pan.val = sub->pan;
 		xc->finetune = sub->fin;
 		xc->gvl = sub->gvl;
 
@@ -224,8 +223,9 @@ static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn
 	sub = get_subinstrument(ctx, xc->ins, xc->key);
 
 	set_effect_defaults(ctx, note, sub, xc, is_toneporta);
-	if (e->ins && sub != NULL)
+	if (e->ins && sub != NULL) {
 		reset_envelopes(ctx, xc);
+	}
 
 	/* Process new volume */
 	if (e->vol) {
@@ -340,6 +340,10 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			 */
 		}
 
+		if (e->ins == 0 && !IS_VALID_INSTRUMENT(xc->old_ins - 1)) {
+			new_invalid_ins = 1;
+		}
+
 		if (new_invalid_ins) {
 			virt_resetchannel(ctx, chn);
 		}
@@ -356,6 +360,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			/* No note */
 			if (sub != NULL) {
 				xc->volume = sub->vol;
+				xc->pan.val = sub->pan;
 				SET(NEW_VOL);
 			}
 		} else {
@@ -369,6 +374,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			sub = get_subinstrument(ctx, xc->ins, key - 1);
 			if (sub != NULL) {
 				xc->volume = sub->vol;
+				xc->pan.val = sub->pan;
 			} else {
 				xc->volume = 0;
 			}
@@ -564,8 +570,9 @@ static int read_event_st3(struct context_data *ctx, struct xmp_event *e, int chn
 	sub = get_subinstrument(ctx, xc->ins, xc->key);
 
 	set_effect_defaults(ctx, note, sub, xc, is_toneporta);
-	if (e->ins && sub != NULL)
+	if (e->ins && sub != NULL) {
 		reset_envelopes(ctx, xc);
+	}
 
 	/* Process new volume */
 	if (e->vol) {
@@ -777,8 +784,16 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 	sub = get_subinstrument(ctx, xc->ins, xc->key);
 
 	set_effect_defaults(ctx, note, sub, xc, is_toneporta);
-	if (note >= 0 && sub != NULL)
-		reset_envelopes(ctx, xc);
+	if (sub != NULL) {
+		if (note >= 0) {
+			if (sub->pan >= 0)
+				xc->pan.val = sub->pan;
+			reset_envelopes(ctx, xc);
+		} else if (e_ins) {
+			if (sub->pan >= 0)
+				xc->pan.val = sub->pan;
+		}
+	}
 	
 	/* Process new volume */
 	if (e->vol) {
@@ -795,8 +810,9 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 	process_fx(ctx, xc, chn, e->note, e->fxt, e->fxp, 0);
 	process_fx(ctx, xc, chn, e->note, e->f2t, e->f2p, 1);
 
-	if (TEST(NEW_VOL))
+	if (TEST(NEW_VOL)) {
 		use_ins_vol = 0;
+	}
 
 	if (sub == NULL) {
 		return 0;
@@ -933,8 +949,9 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 	sub = get_subinstrument(ctx, xc->ins, xc->key);
 
 	set_effect_defaults(ctx, note, sub, xc, is_toneporta);
-	if (e->ins && sub != NULL)
+	if (e->ins && sub != NULL) {
 		reset_envelopes(ctx, xc);
+	}
 
 	/* Process new volume */
 	if (e->vol) {
@@ -946,8 +963,9 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 	process_fx(ctx, xc, chn, e->note, e->f2t, e->f2p, 1);
 	process_fx(ctx, xc, chn, e->note, e->fxt, e->fxp, 0);
 
-	if (TEST(NEW_VOL))
+	if (TEST(NEW_VOL)) {
 		use_ins_vol = 0;
+	}
 
 	if (sub == NULL) {
 		return 0;
@@ -1039,8 +1057,9 @@ static int read_event_smix(struct context_data *ctx, struct xmp_event *e, int ch
 	}
 
 	set_effect_defaults(ctx, note, sub, xc, 0);
-	if (e->ins && sub != NULL)
+	if (e->ins && sub != NULL) {
 		reset_envelopes(ctx, xc);
+	}
 
 	xc->volume = e->vol - 1;
 	SET(NEW_VOL);
