@@ -230,16 +230,18 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 			    } else if (h == 0xf && l != 0) {
 				gvl -= l;
 			    } else {
-		                if (m->quirk & QUIRK_VSALL)
+		                if (m->quirk & QUIRK_VSALL) {
                                     gvl += (h - l) * speed;
-				else
+				} else {
                                     gvl += (h - l) * (speed - 1);
+				}
 			    }
 			} else {
-		            if (m->quirk & QUIRK_VSALL)
+		            if (m->quirk & QUIRK_VSALL) {
                                 gvl += (h - l) * speed;
-			    else
+			    } else {
                                 gvl += (h - l) * (speed - 1);
+			    }
 			}
 		    } else {
                         if ((parm = gvol_memory) != 0)
@@ -252,9 +254,9 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 		    alltmp += cnt_row * speed * base_time;
 		    cnt_row = 0;
 		    if (parm) {
-			if (p->flags & XMP_FLAGS_VBLANK || parm < 0x20)
+			if (p->flags & XMP_FLAGS_VBLANK || parm < 0x20) {
 			    speed = parm;
-			else {
+			} else {
 			    clock += m->time_factor * alltmp / bpm;
 			    alltmp = 0;
 			    bpm = parm;
@@ -287,6 +289,7 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 		    bpm = parm;
 		}
 
+#ifndef LIBXMP_CORE_DISABLE_IT
 		if ((f1 == FX_IT_BPM && p1) || (f2 == FX_IT_BPM && p2)) {
 		    parm = (f1 == FX_IT_BPM) ? p1 : p2;
 		    alltmp += cnt_row * speed * base_time;
@@ -295,17 +298,34 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 		    alltmp = 0;
 
 		    if (MSN(parm) == 0) {
-			bpm -= LSN(parm);
-			if (bpm < 0x20)
-			    bpm = 0x20;
+		        clock += m->time_factor * base_time / bpm;
+			for (i = 1; i < speed; i++) {
+			    bpm -= LSN(parm);
+			    if (bpm < 0x20)
+				bpm = 0x20;
+		            clock += m->time_factor * base_time / bpm;
+			}
+
+			// remove one row at final bpm
+			clock -= m->time_factor * speed * base_time / bpm;
+
 		    } else if (MSN(parm) == 1) {
-			bpm += LSN(parm);
-			if (bpm > 0xff)
-			    bpm = 0xff;
+		        clock += m->time_factor * base_time / bpm;
+			for (i = 1; i < speed; i++) {
+			    bpm += LSN(parm);
+			    if (bpm > 0xff)
+				bpm = 0xff;
+		            clock += m->time_factor * base_time / bpm;
+			}
+
+			// remove one row at final bpm
+			clock -= m->time_factor * speed * base_time / bpm;
+
 		    } else {
 			bpm = parm;
 		    }
 		}
+#endif
 
 		if (f1 == FX_JUMP || f2 == FX_JUMP) {
 		    ord2 = (f1 == FX_JUMP) ? p1 : p2;
